@@ -27,6 +27,8 @@ int block_size=BLOCK_SIZE;
 
 char *backup_suffix = BACKUP_SUFFIX;
 
+static char *rsync_path = RSYNC_NAME;
+
 int make_backups = 0;
 int preserve_links = 0;
 int preserve_perms = 0;
@@ -167,7 +169,7 @@ int do_cmd(char *cmd,char *machine,char *user,char *path,int *f_in,int *f_out)
     args[argc++] = machine;
   }
 
-  args[argc++] = RSYNC_NAME;
+  args[argc++] = rsync_path;
 
   server_options(args,&argc);
 
@@ -357,6 +359,7 @@ static void usage(FILE *f)
   fprintf(f,"-x, --one-file-system    don't cross filesystem boundaries\n");
   fprintf(f,"-B, --block-size SIZE    checksum blocking size\n");  
   fprintf(f,"-e, --rsh COMMAND        specify rsh replacement\n");
+  fprintf(f,"    --rsync-path PATH    specify path to rsync on the remote machine\n");
   fprintf(f,"-C, --cvs-exclude        auto ignore files in the same way CVS does\n");
   fprintf(f,"    --delete             delete files that don't exist on the sending side\n");
   fprintf(f,"-I, --ignore-times       don't exclude files that match length and time\n");
@@ -371,7 +374,7 @@ static void usage(FILE *f)
 }
 
 enum {OPT_VERSION,OPT_SUFFIX,OPT_SENDER,OPT_SERVER,OPT_EXCLUDE,
-      OPT_EXCLUDE_FROM,OPT_DELETE};
+      OPT_EXCLUDE_FROM,OPT_DELETE,OPT_RSYNC_PATH};
 
 static char *short_options = "oblpguDCtcahvrIxne:B:";
 
@@ -382,6 +385,7 @@ static struct option long_options[] = {
   {"delete",      0,     0,    OPT_DELETE},
   {"exclude",     1,     0,    OPT_EXCLUDE},
   {"exclude-from",1,     0,    OPT_EXCLUDE_FROM},
+  {"rsync-path",  1,     0,    OPT_RSYNC_PATH},
   {"one-file-system",0,  0,    'x'},
   {"ignore-times",0,     0,    'I'},
   {"help",        0,     0,    'h'},
@@ -432,7 +436,11 @@ int main(int argc,char *argv[])
 
 	case OPT_SUFFIX:
 	  backup_suffix = optarg;
-	  exit(0);
+	  break;
+
+	case OPT_RSYNC_PATH:
+	  rsync_path = optarg;
+	  break;
 
 	case 'I':
 	  ignore_times = 1;
