@@ -26,6 +26,9 @@
 /* update this if you make incompatible changes */
 #define PROTOCOL_VERSION 9
 
+/* block size to write files in */
+#define WRITE_BLOCK_SIZE (32*1024)
+
 #include "config.h"
 
 #include <sys/types.h>
